Examples
========

The following examples give an idea of how to use EGTtools to model social dynamics:

.. toctree::
    :maxdepth: 2

    examples/hawk_dove_dynamics
    examples/normal_form_game_mc_simulations
    examples/plot_invasion_diagram
    examples/plot_simplex
    examples/plot_simplex_simplified
    examples/examples_of_use


Projects using EGTtools
--------------------------

The `EvoCRD <https://github.com/Socrats/EvoCRD>`_ provide an example of use of EGTtools do
model dynamics in the Collective Risk Dilemma.

You can also find all these examples and a bit more `here <https://github.com/Socrats/egt-tutorial>`_ or launch
the notebooks with `Binder <https://mybinder.org/v2/gh/Socrats/egt-tutorial/HEAD>`_.